==> mastapy-14.0.0rc3-py3-none-any.whl: mastapy/_private/materials/_250.py <==
"""AcousticRadiationEfficiency"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal.python_net import (
    pythonnet_method_call,
    pythonnet_property_get,
    pythonnet_property_set,
    python_net_import,
)
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private import _0
from mastapy._private._internal.cast_exception import CastException

_ACOUSTIC_RADIATION_EFFICIENCY = python_net_import(
    "SMT.MastaAPI.Materials", "AcousticRadiationEfficiency"
)

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    from mastapy._private.materials import _251
    from mastapy._private.math_utility import _1583

    Self = TypeVar("Self", bound="AcousticRadiationEfficiency")
    CastSelf = TypeVar(
        "CastSelf",
        bound="AcousticRadiationEfficiency._Cast_AcousticRadiationEfficiency",
    )


__docformat__ = "restructuredtext en"
__all__ = ("AcousticRadiationEfficiency",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_AcousticRadiationEfficiency:
    """Special nested class for casting AcousticRadiationEfficiency to subclasses."""

    __parent__: "AcousticRadiationEfficiency"

    @property
    def acoustic_radiation_efficiency(
        self: "CastSelf",
    ) -> "AcousticRadiationEfficiency":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class AcousticRadiationEfficiency(_0.APIBase):
    """AcousticRadiationEfficiency

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ACOUSTIC_RADIATION_EFFICIENCY

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def input_type(self: "Self") -> "_251.AcousticRadiationEfficiencyInputType":
        """mastapy.materials.AcousticRadiationEfficiencyInputType"""
        temp = pythonnet_property_get(self.wrapped, "InputType")

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Materials.AcousticRadiationEfficiencyInputType"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.materials._251", "AcousticRadiationEfficiencyInputType"
        )(value)

    @input_type.setter
    @enforce_parameter_types
    def input_type(
        self: "Self", value: "_251.AcousticRadiationEfficiencyInputType"
    ) -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.Materials.AcousticRadiationEfficiencyInputType"
        )
        pythonnet_property_set(self.wrapped, "InputType", value)

    @property
    def knee_frequency(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "KneeFrequency")

        if temp is None:
            return 0.0

        return temp

    @knee_frequency.setter
    @enforce_parameter_types
    def knee_frequency(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "KneeFrequency", float(value) if value is not None else 0.0
        )

    @property
    def low_frequency_power(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "LowFrequencyPower")

        if temp is None:
            return 0.0

        return temp

    @low_frequency_power.setter
    @enforce_parameter_types
    def low_frequency_power(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "LowFrequencyPower",
            float(value) if value is not None else 0.0,
        )

    @property
    def radiation_efficiency_curve(self: "Self") -> "_1583.Vector2DListAccessor":
        """mastapy.math_utility.Vector2DListAccessor"""
        temp = pythonnet_property_get(self.wrapped, "RadiationEfficiencyCurve")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @radiation_efficiency_curve.setter
    @enforce_parameter_types
    def radiation_efficiency_curve(
        self: "Self", value: "_1583.Vector2DListAccessor"
    ) -> None:
        pythonnet_property_set(self.wrapped, "RadiationEfficiencyCurve", value.wrapped)

    @property
    def report_names(self: "Self") -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ReportNames")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    @enforce_parameter_types
    def output_default_report_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped, "OutputDefaultReportTo", file_path if file_path else ""
        )

    def get_default_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = pythonnet_method_call(
            self.wrapped, "GetDefaultReportWithEncodedImages"
        )
        return method_result

    @enforce_parameter_types
    def output_active_report_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped, "OutputActiveReportTo", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_active_report_as_text_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped, "OutputActiveReportAsTextTo", file_path if file_path else ""
        )

    def get_active_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = pythonnet_method_call(
            self.wrapped, "GetActiveReportWithEncodedImages"
        )
        return method_result

    @enforce_parameter_types
    def output_named_report_to(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportTo",
            report_name if report_name else "",
            file_path if file_path else "",
        )

    @enforce_parameter_types
    def output_named_report_as_masta_report(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportAsMastaReport",
            report_name if report_name else "",
            file_path if file_path else "",
        )

    @enforce_parameter_types
    def output_named_report_as_text_to(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportAsTextTo",
            report_name if report_name else "",
            file_path if file_path else "",
        )

    @enforce_parameter_types
    def get_named_report_with_encoded_images(self: "Self", report_name: "str") -> "str":
        """str

        Args:
            report_name (str)
        """
        report_name = str(report_name)
        method_result = pythonnet_method_call(
            self.wrapped,
            "GetNamedReportWithEncodedImages",
            report_name if report_name else "",
        )
        return method_result

    @property
    def cast_to(self: "Self") -> "_Cast_AcousticRadiationEfficiency":
        """Cast to another type.

        Returns:
            _Cast_AcousticRadiationEfficiency
        """
        return _Cast_AcousticRadiationEfficiency(self)

==> mastapy-14.0.3-py3-none-any.whl: mastapy/_private/materials/_250.py <==
"""AcousticRadiationEfficiency"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private import _0
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

_ACOUSTIC_RADIATION_EFFICIENCY = python_net_import(
    "SMT.MastaAPI.Materials", "AcousticRadiationEfficiency"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.materials import _251
    from mastapy._private.math_utility import _1585

    Self = TypeVar("Self", bound="AcousticRadiationEfficiency")
    CastSelf = TypeVar(
        "CastSelf",
        bound="AcousticRadiationEfficiency._Cast_AcousticRadiationEfficiency",
    )


__docformat__ = "restructuredtext en"
__all__ = ("AcousticRadiationEfficiency",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_AcousticRadiationEfficiency:
    """Special nested class for casting AcousticRadiationEfficiency to subclasses."""

    __parent__: "AcousticRadiationEfficiency"

    @property
    def acoustic_radiation_efficiency(
        self: "CastSelf",
    ) -> "AcousticRadiationEfficiency":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class AcousticRadiationEfficiency(_0.APIBase):
    """AcousticRadiationEfficiency

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ACOUSTIC_RADIATION_EFFICIENCY

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def input_type(self: "Self") -> "_251.AcousticRadiationEfficiencyInputType":
        """mastapy.materials.AcousticRadiationEfficiencyInputType"""
        temp = pythonnet_property_get(self.wrapped, "InputType")

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Materials.AcousticRadiationEfficiencyInputType"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.materials._251", "AcousticRadiationEfficiencyInputType"
        )(value)

    @input_type.setter
    @enforce_parameter_types
    def input_type(
        self: "Self", value: "_251.AcousticRadiationEfficiencyInputType"
    ) -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.Materials.AcousticRadiationEfficiencyInputType"
        )
        pythonnet_property_set(self.wrapped, "InputType", value)

    @property
    def knee_frequency(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "KneeFrequency")

        if temp is None:
            return 0.0

        return temp

    @knee_frequency.setter
    @enforce_parameter_types
    def knee_frequency(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "KneeFrequency", float(value) if value is not None else 0.0
        )

    @property
    def low_frequency_power(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "LowFrequencyPower")

        if temp is None:
            return 0.0

        return temp

    @low_frequency_power.setter
    @enforce_parameter_types
    def low_frequency_power(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "LowFrequencyPower",
            float(value) if value is not None else 0.0,
        )

    @property
    def radiation_efficiency_curve(self: "Self") -> "_1585.Vector2DListAccessor":
        """mastapy.math_utility.Vector2DListAccessor"""
        temp = pythonnet_property_get(self.wrapped, "RadiationEfficiencyCurve")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @radiation_efficiency_curve.setter
    @enforce_parameter_types
    def radiation_efficiency_curve(
        self: "Self", value: "_1585.Vector2DListAccessor"
    ) -> None:
        pythonnet_property_set(self.wrapped, "RadiationEfficiencyCurve", value.wrapped)

    @property
    def report_names(self: "Self") -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ReportNames")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    @enforce_parameter_types
    def output_default_report_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped, "OutputDefaultReportTo", file_path if file_path else ""
        )

    def get_default_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = pythonnet_method_call(
            self.wrapped, "GetDefaultReportWithEncodedImages"
        )
        return method_result

    @enforce_parameter_types
    def output_active_report_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped, "OutputActiveReportTo", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_active_report_as_text_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped, "OutputActiveReportAsTextTo", file_path if file_path else ""
        )

    def get_active_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = pythonnet_method_call(
            self.wrapped, "GetActiveReportWithEncodedImages"
        )
        return method_result

    @enforce_parameter_types
    def output_named_report_to(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportTo",
            report_name if report_name else "",
            file_path if file_path else "",
        )

    @enforce_parameter_types
    def output_named_report_as_masta_report(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportAsMastaReport",
            report_name if report_name else "",
            file_path if file_path else "",
        )

    @enforce_parameter_types
    def output_named_report_as_text_to(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportAsTextTo",
            report_name if report_name else "",
            file_path if file_path else "",
        )

    @enforce_parameter_types
    def get_named_report_with_encoded_images(self: "Self", report_name: "str") -> "str":
        """str

        Args:
            report_name (str)
        """
        report_name = str(report_name)
        method_result = pythonnet_method_call(
            self.wrapped,
            "GetNamedReportWithEncodedImages",
            report_name if report_name else "",
        )
        return method_result

    @property
    def cast_to(self: "Self") -> "_Cast_AcousticRadiationEfficiency":
        """Cast to another type.

        Returns:
            _Cast_AcousticRadiationEfficiency
        """
        return _Cast_AcousticRadiationEfficiency(self)
